==> portal-transparencia-1.98.1.zip: BOOT-INF/classes/db/sql/aise/receitas-arrecadacao-por-bairros.sql <==

SELECT BAIRRO, LOGRADOURO, DESCRICAO, RECEITA,
       SUM(VALORRECEITA) AS VALORLANCADO,
       SUM(VALORRENUNCIA) AS VALORRENUNCIA,
       SUM(TOTALLANCADO) AS VALORLANCADOLIQUIDO,
       SUM(TOTALPAGO) AS VALORPAGO,
       SUM(TOTALCANCELADO) AS VALORCANCELADO,
       SUM(OUTRASBAIXAS) AS OUTRASBAIXAS,
       SUM(VALORLANCADOPERIODO) AS VALORLANCADOPERIODO,
       SUM(VALORINADIMPLENTE) AS VALORINADIMPLENTE,
       COUNT(DISTINCT CADASTROGERAL) TOTALCADASTRO,
       COUNT(DISTINCT CASE
               WHEN VALORRENUNCIA > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTRORENUNCIA,
       COUNT(DISTINCT CASE
               WHEN PAGO > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTROPAGO,
       COUNT(DISTINCT CASE
               WHEN VALORINADIMPLENTE > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTROINADIMPLENTE
  FROM (SELECT DEB.IDDEBITO AS IDDEBITO,
               DEB.CADASTROGERAL AS CADASTROGERAL,
               CASE WHEN TRIM(BAR.DESCRICAO) IS NOT NULL THEN TRIM(BAR.DESCRICAO) ELSE 'Outros' END as BAIRRO,
               CASE WHEN TRIM(LOGR.DESCRICAO) IS NOT NULL THEN TRIM(LOGR.DESCRICAO) ELSE 'Outros' END AS LOGRADOURO,
               REC.RECEITA AS RECEITA,
               TRIBRECEITA.descricao AS DESCRICAO,
               RECEITA.VALORRECEITA AS VALORRECEITA,
               RECEITA.VALORRENUNCIA AS VALORRENUNCIA,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 2 THEN
                      1
                     ELSE
                      0
                   END) PAGO,
               SUM(REC.VALOR) AS TOTALLANCADO,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 2 THEN
                      REC.VALOR
                     ELSE
                      0
                   END) AS TOTALPAGO,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 7 THEN
                      REC.VALOR
                     ELSE
                      0
                   END) AS TOTALCANCELADO,
               SUM(CASE WHEN SITP.TIPOSITUACAOPARCELA NOT IN (1,2,7) THEN REC.VALOR ELSE 0 END) AS OUTRASBAIXAS,
               SUM(CASE
                     WHEN (PAR.DATAVENCIMENTO < CURRENT_DATE) THEN
                      REC.VALOR
                     else
                      0
                   END) AS VALORLANCADOPERIODO,
               SUM(CASE
                     WHEN (PAR.DATAVENCIMENTO < CURRENT_DATE AND SITP.TIPOSITUACAOPARCELA = 1) THEN
                      REC.VALOR
                     else
                      0
                   END) AS VALORINADIMPLENTE
          FROM TRIBDEBITO DEB
          LEFT OUTER JOIN TRIBDEBITOPARCELA PAR ON DEB.ENTIDADE = PAR.ENTIDADE
                                               AND DEB.EXERCICIO = PAR.EXERCICIO
                                               AND DEB.TIPOCADASTRO = PAR.TIPOCADASTRO
                                               AND DEB.CADASTROGERAL = PAR.CADASTROGERAL
                                               AND DEB.GUIARECOLHIMENTO = PAR.GUIARECOLHIMENTO
                                               AND DEB.SUBDIVIDA = PAR.SUBDIVIDA
          LEFT OUTER JOIN TRIBSITUACAOPARCELA SITP ON SITP.SITUACAOPARCELA = PAR.SITUACAODEBITO
          LEFT OUTER JOIN TRIBDEBITORECEITA RECEITA ON RECEITA.ENTIDADE = DEB.ENTIDADE
                                                   AND RECEITA.EXERCICIO = DEB.EXERCICIO
                                                   AND RECEITA.TIPOCADASTRO = DEB.TIPOCADASTRO
                                                   AND RECEITA.CADASTROGERAL = DEB.CADASTROGERAL
                                                   AND RECEITA.GUIARECOLHIMENTO = DEB.GUIARECOLHIMENTO
                                                   AND RECEITA.SUBDIVIDA = DEB.SUBDIVIDA
          LEFT OUTER JOIN TRIBDEBITOPARCELARECEITA REC ON PAR.ENTIDADE = REC.ENTIDADE
                                                      AND PAR.EXERCICIO = REC.EXERCICIO
                                                      AND PAR.TIPOCADASTRO = REC.TIPOCADASTRO
                                                      AND PAR.CADASTROGERAL = REC.CADASTROGERAL
                                                      AND PAR.GUIARECOLHIMENTO = REC.GUIARECOLHIMENTO
                                                      AND PAR.SUBDIVIDA = REC.SUBDIVIDA
                                                      AND PAR.PARCELA = REC.PARCELA
                                                      AND RECEITA.RECEITA = REC.RECEITA
          LEFT OUTER JOIN TRIBRECEITA TRIBRECEITA ON TRIBRECEITA.ENTIDADE = REC.ENTIDADE
                                                   AND TRIBRECEITA.EXERCICIO = REC.EXERCICIO
                                                   AND TRIBRECEITA.RECEITA = REC.RECEITA
          LEFT OUTER JOIN TRIBCADASTROGERAL GER ON GER.TIPOCADASTRO = DEB.TIPOCADASTRO
                                               AND GER.CADASTROGERAL = DEB.CADASTROGERAL
          LEFT OUTER JOIN BAIRRO BAR ON BAR.CIDADE = GER.CIDADE
                                    AND BAR.BAIRRO = GER.BAIRRO
          LEFT OUTER JOIN LOGRADOURO LOGR ON LOGR.CIDADE = BAR.CIDADE
                                         AND LOGR.LOGRADOURO = GER.LOGRADOURO
 WHERE DEB.ENTIDADE = :entidade
   AND DEB.EXERCICIO = :exercicio
   AND DEB.GUIARECOLHIMENTO IN (:guiasRecolhimento)
   AND REC.RECEITA = :receita
   $[filtroLogradouro]
   AND TRIM(BAR.DESCRICAO) = :bairro
         GROUP BY DEB.IDDEBITO,
                  DEB.CADASTROGERAL,
                  TRIM(BAR.DESCRICAO),
                  TRIM(LOGR.DESCRICAO),
                  REC.RECEITA,
                  RECEITA.VALORRECEITA,
                  RECEITA.VALORRENUNCIA,
                  TRIBRECEITA.DESCRICAO) T
GROUP BY BAIRRO, LOGRADOURO, DESCRICAO, RECEITA
ORDER BY BAIRRO, LOGRADOURO

==> portal-transparencia-2.020.0.zip: BOOT-INF/classes/db/sql/aise/receitas-arrecadacao-por-bairros.sql <==

SELECT BAIRRO, LOGRADOURO, DESCRICAO, RECEITA,
       SUM(VALORRECEITA) AS VALORLANCADO,
       SUM(VALORRENUNCIA) AS VALORRENUNCIA,
       SUM(TOTALLANCADO) AS VALORLANCADOLIQUIDO,
       SUM(TOTALPAGO) AS VALORPAGO,
       SUM(TOTALCANCELADO) AS VALORCANCELADO,
       SUM(OUTRASBAIXAS) AS OUTRASBAIXAS,
       SUM(VALORLANCADOPERIODO) AS VALORLANCADOPERIODO,
       SUM(VALORINADIMPLENTE) AS VALORINADIMPLENTE,
       COUNT(DISTINCT CADASTROGERAL) TOTALCADASTRO,
       COUNT(DISTINCT CASE
               WHEN VALORRENUNCIA > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTRORENUNCIA,
       COUNT(DISTINCT CASE
               WHEN PAGO > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTROPAGO,
       COUNT(DISTINCT CASE
               WHEN VALORINADIMPLENTE > 0 THEN
                CADASTROGERAL
               ELSE
                NULL
             END) AS TOTALCADASTROINADIMPLENTE
  FROM (SELECT DEB.IDDEBITO AS IDDEBITO,
               DEB.CADASTROGERAL AS CADASTROGERAL,
               CASE WHEN TRIM(BAR.DESCRICAO) IS NOT NULL THEN TRIM(BAR.DESCRICAO) ELSE 'Outros' END as BAIRRO,
               CASE WHEN TRIM(LOGR.DESCRICAO) IS NOT NULL THEN TRIM(LOGR.DESCRICAO) ELSE 'Outros' END AS LOGRADOURO,
               REC.RECEITA AS RECEITA,
               TRIBRECEITA.descricao AS DESCRICAO,
               RECEITA.VALORRECEITA AS VALORRECEITA,
               RECEITA.VALORRENUNCIA AS VALORRENUNCIA,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 2 THEN
                      1
                     ELSE
                      0
                   END) PAGO,
               SUM(REC.VALOR) AS TOTALLANCADO,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 2 THEN
                      REC.VALOR
                     ELSE
                      0
                   END) AS TOTALPAGO,
               SUM(CASE
                     WHEN SITP.TIPOSITUACAOPARCELA = 7 THEN
                      REC.VALOR
                     ELSE
                      0
                   END) AS TOTALCANCELADO,
               SUM(CASE WHEN SITP.TIPOSITUACAOPARCELA NOT IN (1,2,7) THEN REC.VALOR ELSE 0 END) AS OUTRASBAIXAS,
               SUM(CASE
                     WHEN (PAR.DATAVENCIMENTO < CURRENT_DATE) THEN
                      REC.VALOR
                     else
                      0
                   END) AS VALORLANCADOPERIODO,
               SUM(CASE
                     WHEN (PAR.DATAVENCIMENTO < CURRENT_DATE AND SITP.TIPOSITUACAOPARCELA = 1) THEN
                      REC.VALOR
                     else
                      0
                   END) AS VALORINADIMPLENTE
          FROM ${db.aise.schema}.TRIBDEBITO DEB
          LEFT OUTER JOIN ${db.aise.schema}.TRIBDEBITOPARCELA PAR ON DEB.ENTIDADE = PAR.ENTIDADE
                                               AND DEB.EXERCICIO = PAR.EXERCICIO
                                               AND DEB.TIPOCADASTRO = PAR.TIPOCADASTRO
                                               AND DEB.CADASTROGERAL = PAR.CADASTROGERAL
                                               AND DEB.GUIARECOLHIMENTO = PAR.GUIARECOLHIMENTO
                                               AND DEB.SUBDIVIDA = PAR.SUBDIVIDA
          LEFT OUTER JOIN ${db.aise.schema}.TRIBSITUACAOPARCELA SITP ON SITP.SITUACAOPARCELA = PAR.SITUACAODEBITO
          LEFT OUTER JOIN ${db.aise.schema}.TRIBDEBITORECEITA RECEITA ON RECEITA.ENTIDADE = DEB.ENTIDADE
                                                   AND RECEITA.EXERCICIO = DEB.EXERCICIO
                                                   AND RECEITA.TIPOCADASTRO = DEB.TIPOCADASTRO
                                                   AND RECEITA.CADASTROGERAL = DEB.CADASTROGERAL
                                                   AND RECEITA.GUIARECOLHIMENTO = DEB.GUIARECOLHIMENTO
                                                   AND RECEITA.SUBDIVIDA = DEB.SUBDIVIDA
          LEFT OUTER JOIN ${db.aise.schema}.TRIBDEBITOPARCELARECEITA REC ON PAR.ENTIDADE = REC.ENTIDADE
                                                      AND PAR.EXERCICIO = REC.EXERCICIO
                                                      AND PAR.TIPOCADASTRO = REC.TIPOCADASTRO
                                                      AND PAR.CADASTROGERAL = REC.CADASTROGERAL
                                                      AND PAR.GUIARECOLHIMENTO = REC.GUIARECOLHIMENTO
                                                      AND PAR.SUBDIVIDA = REC.SUBDIVIDA
                                                      AND PAR.PARCELA = REC.PARCELA
                                                      AND RECEITA.RECEITA = REC.RECEITA
          LEFT OUTER JOIN ${db.aise.schema}.TRIBRECEITA TRIBRECEITA ON TRIBRECEITA.ENTIDADE = REC.ENTIDADE
                                                   AND TRIBRECEITA.EXERCICIO = REC.EXERCICIO
                                                   AND TRIBRECEITA.RECEITA = REC.RECEITA
          LEFT OUTER JOIN ${db.aise.schema}.TRIBCADASTROGERAL GER ON GER.TIPOCADASTRO = DEB.TIPOCADASTRO
                                               AND GER.CADASTROGERAL = DEB.CADASTROGERAL
          LEFT OUTER JOIN ${db.aise.schema}.BAIRRO BAR ON BAR.CIDADE = GER.CIDADE
                                    AND BAR.BAIRRO = GER.BAIRRO
          LEFT OUTER JOIN ${db.aise.schema}.LOGRADOURO LOGR ON LOGR.CIDADE = BAR.CIDADE
                                         AND LOGR.LOGRADOURO = GER.LOGRADOURO
 WHERE DEB.ENTIDADE = :entidade
   AND DEB.EXERCICIO = :exercicio
   AND DEB.GUIARECOLHIMENTO IN (:guiasRecolhimento)
   AND REC.RECEITA = :receita
   $[filtroLogradouro]
   AND TRIM(BAR.DESCRICAO) = :bairro
         GROUP BY DEB.IDDEBITO,
                  DEB.CADASTROGERAL,
                  TRIM(BAR.DESCRICAO),
                  TRIM(LOGR.DESCRICAO),
                  REC.RECEITA,
                  RECEITA.VALORRECEITA,
                  RECEITA.VALORRENUNCIA,
                  TRIBRECEITA.DESCRICAO) T
GROUP BY BAIRRO, LOGRADOURO, DESCRICAO, RECEITA
ORDER BY BAIRRO, LOGRADOURO
